@@ -79,6 +79,7 @@ CATEGORY_MAP = {
     "imagebam"       : "ImageBam",
     "imagefap"       : "ImageFap",
     "imagepond"      : "ImagePond",
+    "imgadult"       : "ImgAdult",
     "imgbb"          : "ImgBB",
     "imgbox"         : "imgbox",
     "imagechest"     : "ImageChest",
@@ -91,6 +92,7 @@ CATEGORY_MAP = {
     "jpgfish"        : "JPG Fish",
     "kabeuchi"       : "かべうち",
     "schalenetwork"  : "Schale Network",
+    "leakgallery"    : "Leak Gallery",
     "livedoor"       : "livedoor Blog",
     "lofter"         : "LOFTER",
     "ohpolly"        : "Oh Polly",
@@ -236,6 +238,7 @@ SUBCATEGORY_MAP = {
         "user-images": ("User Images", "Image Reactions"),
         "user-posts" : "User Posts",
         "user-videos": ("User Videos", "Video Reactions"),
+        "generated": "Generated Files",
     },
     "coomer": {
         "discord"       : "",
@@ -258,6 +261,9 @@ SUBCATEGORY_MAP = {
     "discord": {
         "direct-message" : "",
     },
+    "facebook": {
+        "photos" : "Profile Photos",
+    },
     "fanbox": {
         "supporting": "Supported User Feed",
         "redirect"  : "Pixiv Redirects",
@@ -287,6 +293,9 @@ SUBCATEGORY_MAP = {
         "saved": "Saved Posts",
         "tagged": "Tagged Posts",
     },
+    "itaku": {
+        "posts": "",
+    },
     "iwara": {
         "user-images": "User Images",
         "user-videos": "User Videos",
@@ -297,6 +306,10 @@ SUBCATEGORY_MAP = {
         "discord-server": "",
         "posts"         : "",
     },
+    "leakgallery": {
+        "trending" : "Trending Medias",
+        "mostliked": "Most Liked Posts",
+    },
     "lensdump": {
         "albums": "",
     },
@@ -482,6 +495,7 @@ AUTH_MAP = {
     "instagram"      : _COOKIES,
     "iwara"          : "Supported",
     "kemono"         : "Supported",
+    "madokami"       : "Required",
     "mangadex"       : "Supported",
     "mangoxo"        : "Supported",
     "mastodon.social": _OAUTH,
@@ -624,9 +638,9 @@ def build_extractor_list():
     default["e-hentai"] = default["exhentai"]
     domains["e-hentai"] = domains["exhentai"].replace("x", "-")
 
-    # add coomer.su
+    # add coomer.st
     default["coomer"] = default["kemono"]
-    domains["coomer"] = domains["kemono"].replace("kemono", "coomer")
+    domains["coomer"] = "https://coomer.st/"
 
     # add wikifeetx.com
     default["wikifeetx"] = default["wikifeet"]
