@@ -35,6 +35,21 @@ __tests__ = (
     "#sha1_content": "54d548743cd67799a62c77cbae97cfa0fec1b7e9",
 },
 
+{
+    "#url"     : "https://aibooru.online/posts/18315",
+    "#comment" : "ugoira (#7630)",
+    "#category": ("Danbooru", "aibooru", "post"),
+    "#class"   : danbooru.DanbooruPostExtractor,
+    "#options" : {"ugoira": True},
+    "#results" : "https://cdn.aibooru.download/original/f9/6b/f96b2b3254884ab527fab0a7e9c39ba9.zip",
+
+    "_ugoira_original"     : False,
+    "_ugoira_frame_data[*]": {
+        "file" : r"re:^0000\d\d\.jpg$",
+        "delay": int,
+    },
+},
+
 {
     "#url"     : "https://aibooru.online/explore/posts/popular",
     "#category": ("Danbooru", "aibooru", "popular"),
